create_clock -period 8.0 -name fpga_clk [get_ports fpga_clk]

# Constrains PLL outputs.  One output has 90 degree phase-shift for transmit clock
derive_pll_clocks

derive_clock_uncertainty

# Put a generated clock on output clock port to be referenced by set_output_delay constraints.  The clock is edge-aligned with the FPGA's clock
create_generated_clock -source [get_pins {inst1|altpll_component|auto_generated|pll1|clk[0]}] -name ssync_tx_clk_ext [get_ports {ssync_tx_clk}] 

# Case 6: Alternative method, FPGA is Transmitter
# This design is identical to Case 4 except for .sdc changes.  The -phase 90 was removed from the above create_generated_clock because the alternative method has edge-aligned clocks
# The default setup relationship is now 4ns and hold relationship is 0ns.
# The external delays were all increased by 2ns, from 1.2ns and -1.1ns to 3.2ns and 0.9ns
set_output_delay -clock ssync_tx_clk_ext -max 3.2 [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -min 0.9 [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -max 3.2 [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
set_output_delay -clock ssync_tx_clk_ext -min 0.9 [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay


##### Same Edge Transfer Solution ######
# To run, comment out lines 15-18 and uncomment lines 23-28.  
# Multicycles are necessary to tell TimeQuest that this is a same edge trasfer
# The multicycle modifies the setup relationship to 0ns and the hold relationship to -4ns
# The external delays were all decreased by 2ns, from 1.2ns and -1.1ns to -0.8ns and -3.1ns: 
#set_multicycle_path -setup -rise_from [get_clocks {inst1|altpll_component|auto_generated|pll1|clk[0]}] -rise_to [get_clocks {ssync_tx_clk_ext}] 0
#set_multicycle_path -setup -fall_from [get_clocks {inst1|altpll_component|auto_generated|pll1|clk[0]}] -fall_to [get_clocks {ssync_tx_clk_ext}] 0
#set_output_delay -clock ssync_tx_clk_ext -max -0.8 [get_ports {ssync_tx_data[*]}]
#set_output_delay -clock ssync_tx_clk_ext -min -3.1 [get_ports {ssync_tx_data[*]}]
#set_output_delay -clock ssync_tx_clk_ext -max -0.8 [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
#set_output_delay -clock ssync_tx_clk_ext -min -3.1 [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
