
set clk_period 8.0
create_clock -period $clk_period -name fpga_clk [get_ports fpga_clk]

# Constrains PLL outputs
derive_pll_clocks

derive_clock_uncertainty

# Put a generated clock on output clock port to be referenced by set_output_delay constraints.  Saying the clock is externally phase-shifted 90 degrees 
# tells TimeQuest that the external device is shifting the clock into the middle of the data eye, and so the FPGA should send its data/clock edge-aligned
create_generated_clock -source [get_pins {inst1|altpll_component|auto_generated|pll1|clk[0]}] -name ssync_tx_clk_ext [get_ports {ssync_tx_clk}] -phase 90

# Case 4:  FPGA sends the clock and data edge-aligned

set 90degrees [expr $clk_period / 4.0] ;# 90 degrees, which will be the setup and hold relationship with Explicit Clock Shift Method

# Tx Skew Constraint #1: Constraining the transmitter to have 0ns of skew(which it will fail)
# Allowed output skew on transmitter.  First compile with these set to 0, so no skew is allowed.  
#set tx_output_skew_max 0.0 
#set tx_output_skew_min -0.0

# Tx Skew Constraint #2: Re-constraining the transmitter based on how much it failed Pass #1.
# In my compile, the transmitter failed setup analysis by -355ps and hold analysis by -352ps.  I will loosen the requirements so it meets timing:
set tx_output_skew_max 0.360 
set tx_output_skew_min -0.360
# There is no need to re-compile, as re-running timing analysis will show the new constraints work.

# Tx Skew Constraint #3 (Optional)
# If the user has lots of slack after compiling the receiver, they can use some of that to loosen the transmitter skew requirement(which tightens the receiver requirement).
# For example, the following loosens timing by 400ps:
#set tx_output_skew_max 0.760 
#set tx_output_skew_min -0.760

# We constrain not by saying how much skew is allowed, but how much skew is external to the transmitter.  This is based on the clock period:
set ext_skew_max [expr $90degrees - $tx_output_skew_max]
set ext_skew_min [expr -$90degrees - $tx_output_skew_min]

set_output_delay -clock ssync_tx_clk_ext -max $ext_skew_max [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -min $ext_skew_min [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -max $ext_skew_max [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay
set_output_delay -clock ssync_tx_clk_ext -min $ext_skew_min [get_ports {ssync_tx_data[*]}] -clock_fall -add_delay

