create_clock -period 4.0 -name fpga_clk [get_ports fpga_clk]

# Constrains PLL outputs.  One output has 90 degree phase-shift for transmit clock
derive_pll_clocks

derive_clock_uncertainty

# Put a generated clock on output clock port to be referenced by set_output_delay constraints.  Note the -invert option, which says the clock is being inverted on the way out.  This is important
# since Quartus doesn't recognize the DDR output with VCC/GND switched as inverting the clock
create_generated_clock -source [get_pins {inst1|altpll_component|auto_generated|pll1|clk[0]}] -name ssync_tx_clk_ext [get_ports {ssync_tx_clk}] -invert

# Case 3:  FPGA inverts the clock so it is transmitted center-aligned with the data 
# External Delays: The external -max delay is 1.2ns and -min is -1.1ns.  This means the external device may skew the data +1.2ns to -1.1ns compared to the clock  
# FPGA Requirement - Setup: The setup relationship is 2ns and the -max value is 1.2ns.  The FPGA's output data path can be 0.8ns longer than the clock path and still meet timing.
# FPGA Requirement - Hold: The hold relationship is -2ns and the -min is -1.1ns.  The FPGA's data path can be 0.9ns shorter than the clock path and still meet timming.
# Since this is Case 3, the FPGA does a 90 degree shift of the outgoing clock on top of these skew requirements
set_output_delay -clock ssync_tx_clk_ext -max 1.2 [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -min -1.1 [get_ports {ssync_tx_data[*]}]

