create_clock -period 4.0 -name fpga_clk [get_ports fpga_clk]

# Constrains PLL output
derive_pll_clocks

derive_clock_uncertainty

# Put a generated clock on output clock port to be referenced by set_output_delay constraints.  Saying the clock is externally phase-shifted 180 degrees 
# tells TimeQuest that the external device is shifting the clock into the middle of the data eye, and so the FPGA should send its data/clock edge-aligned
create_generated_clock -source [get_pins {inst1|altpll_component|auto_generated|pll1|clk[0]}] -name ssync_tx_clk_ext [get_ports {ssync_tx_clk}] -invert

# Case 4:  FPGA sends the clock and data edge-aligned
# External Delays: The external -max delay is 1.2ns and -min is -1.1ns.  This means the external device may skew the data +1.2ns to -1.1ns compared to the clock.  It will also shift 
#		the clock 90 degrees to center-align it with the data
# FPGA Requirement - Setup: The setup relationship is 2ns and the -max value is 1.2ns.  The FPGA's output data path can be 0.8ns longer than the clock path and still meet timing.
# FPGA Requirement - Hold: The hold relationship is -2ns and the -min is -1.1ns.  The FPGA's data path can be 0.9ns shorter than the clock path and still meet timming.
set_output_delay -clock ssync_tx_clk_ext -max 1.2 [get_ports {ssync_tx_data[*]}]
set_output_delay -clock ssync_tx_clk_ext -min -1.1 [get_ports {ssync_tx_data[*]}]


