# Shift clock coming into the FPGA by 90 degrees so it is explicitly shifted from external virtual clock ssync_clk_ext
create_clock -period 8.0 -name ssync_rx_clk [get_ports ssync_rx_clk] 

derive_pll_clocks

derive_clock_uncertainty

################### ADS4149 -> FPGA Interface ####################
# Create virtual clock for ADS4149.  Phase-shift it 90 degrees to say it is center-aligned
create_clock -period 8.0 -name ssync_clk_ext -waveform {2.0 6.0}

# The device does not spec what it is actually doing, but what it can provide.  We will use our relationship to figure out what the ADS4149 is actually doing
# We will need to know the setup relationship and hold relationship to perform this calculation, which are just +90 degrees and -90 degrees in Explicit Clock Shift Mode
set relationship 2.0 

# TI ADS4149 datasheet says it can provide a Tsu and Th to the FPGA:
set adc_tsu 0.75
set adc_th 0.35 

# Need to calculate whave ADS4149 is actually doing
set adc_skew_max [expr $relationship - $adc_tsu] ; # 2 - 0.75 = 1.25
set adc_skew_min [expr -$relationship - (-$adc_th)] ; # -2 - (-0.35) = -1.65

# The board skew need to be accounted for.  Positive means data is longer than clk, negative means it is shorter than clk.  I made up some values:
set board_data2clk_skew_max 0.05
set board_data2clk_skew_min -0.05

# Now just add the ADC skew and board skew to calculate external delays:
set ssync_in_max [expr $adc_skew_max + $board_data2clk_skew_max] ;# 1.25 + 0.05 = 1.30
set ssync_in_min [expr $adc_skew_min + $board_data2clk_skew_min] ;# -1.65 + -0.05 = -1.70

set_input_delay -clock ssync_clk_ext -max $ssync_in_max [get_ports {ssync_rx_data[*]}]
set_input_delay -clock ssync_clk_ext -min $ssync_in_min [get_ports {ssync_rx_data[*]}]
set_input_delay -clock ssync_clk_ext -max $ssync_in_max [get_ports {ssync_rx_data[*]}] -clock_fall -add_delay
set_input_delay -clock ssync_clk_ext -min $ssync_in_min [get_ports {ssync_rx_data[*]}] -clock_fall -add_delay
##################################################################
